﻿//css_ref System.Data;
//css_ref System.Transactions;
//css_ref System.Xml;
//css_ref Interop.SAPbobsCOM.dll;
//css_ref log4net.dll;
//css_ref Produmex.Foundation.Data.dll;
//css_ref Produmex.Foundation.Data.Sbo.dll;
//css_ref Produmex.Foundation.dll;
//css_ref Produmex.Foundation.Sbo.dll;
//css_ref Produmex.Sbo.Logex.Data.dll;

using System;
using System.Transactions;
using Produmex.Foundation.Reflection;
using Produmex.Foundation.Data.Sbo;
using Produmex.Foundation.Data.Sbo.Attributes;
using Produmex.Foundation.Data.Sbo.BusinessObjects;
using Produmex.Foundation.Data.Sbo.BusinessObjects.Convertors;
using Produmex.Foundation.Data.Sbo.BusinessObjects.Definitions;
using Produmex.Foundation.Data.Sbo.Providers;
using Produmex.Sbo.Logex.Data;
using Produmex.Sbo.Logex.Data.BusinessObjects;
using Produmex.Sbo.Logex.Data.BusinessObjects.Definitions;
using Produmex.Sbo.Logex.Data.Providers;
using Produmex.Sbo.Logex.Digicel;
using Produmex.Sbo.Logex.Data.BusinessObjects.Definitions.Tables;


namespace AddUpdateData
{
    class Program
    {
        const string CONNECTION_STRING = "Server=localhost;CompanyDB=SBODemo_US;ExtraDb=PMX_SBODemo_US;UseTrusted=False;DbUserName=sa;DbPassword=B1Admin;UserName=manager;Password=produmex;Pooling=True;MinPoolSize=2;MaxPoolSize=10;ServerType=MSSQL2005;DBCultureInfo=en-US;LicenseServer=localhost:30000";

        static void Main(string[] args)
        {
            using (TransactionScope scope = PmxDbConnection.GetNewTransactionScope())
            {
                using (SboConnection conn = new SboConnection(CONNECTION_STRING))
                {
                    conn.Open(); //Open connection to SAP
                    Console.WriteLine("Connection is open to database");

                    PmxDbVersionUpdaterProvider updProv = new PmxDbVersionUpdaterProvider(conn);

                    updProv.AddUpdateExtension(Produmex.Sbo.Logex.Digicel.BusinessObjects.Definitions.PmxExtensionCodes.DIGICEL_SERIAL_NUMBER_CONTROLLER, "SerialNumberController - (Digicel) Control the serial numbers", typeof(Produmex.Sbo.Logex.Digicel.Generators.SerialNumberController.SerialNumberController), Produmex.Sbo.Logex.Data.BusinessObjects.Definitions.PmxExtensionTypeCodes.ISERIALNUMBERCONTROLLER);
                    updProv.AddUpdateUserDefinedTable(typeof(PmxSerialEvents));
                    updProv.AddUpdateUserDefinedObject(typeof(PmxSerialEvents));
                    updProv.AddUpdateUserDefinedTable(typeof(PmxReasonLink));
                    updProv.AddUpdateUserDefinedObject(typeof(PmxReasonLink));
                    //updProv.AddUpdateExtensionParameter(Produmex.Sbo.Logex.Digicel.BusinessObjects.Definitions.PmxExtensionCodes.DIGICEL_SERIAL_NUMBER_CONTROLLER,

                    updProv.AddUpdateExtensionParameter(
                    Produmex.Sbo.Logex.Digicel.Generators.SerialNumberController.SerialNumberController.IDs.ExtParamAskForDestLocBeforeSerialNumbers,
                    "Ask for dest. loc. before entering serial numbers? (Y/N)",
                    Produmex.Sbo.Logex.Digicel.Generators.SerialNumberController.SerialNumberController.IDs.ExtCode,
                    Produmex.Foundation.Data.Sbo.BusinessObjects.Definitions.PmxExtensionCodes.SYSTEM_BOOL_CONVERTOR,
                    "False",
                    PmxExtensionParameterCodes.SERIAL_CONTROLLER_ASK_DEST_LOC_BEFORE_SERIAL);


                }

                //Complete transaction
                scope.Complete();
            }
        }

        /// <summary>
        /// Add/Update <see cref="PmxExtension"/>
        /// </summary>
        /// <param name="code">The code of the extension.</param>
        /// <param name="name">The name of the extension.</param>
        /// <param name="type">The type of the extension.</param>
        /// <param name="extensionTypeCode">The extension type code.</param>
        /// <param name="conn">The SBO connection</param>
        private static void AddUpdateExtension( string code, string name, Type type, string extensionTypeCode, SboConnection conn )
        {
            PmxExtensionProvider prov = new PmxExtensionProvider( conn );
            PmxExtension extension = null;
            try
            {
                bool newBO = false;
                extension = prov.GetBO( code );
                if ( extension == null )
                {
                    newBO = true;
                    extension = prov.GetNewBO();
                    extension.Code = code;
                }
                extension.Name = name;
                extension.ExtensionTypeCode = extensionTypeCode;
                extension.Type = ReflectionHelper.GetTypeAndAssemblyName( type );
                if ( newBO )
                {
                    prov.AddBO( extension );
                }
                else
                {
                    prov.UpdateBO( extension );
                }
            }
            finally
            {
                if ( extension != null ) extension.Dispose();
            }
        }


    }
}
